Class: Google::Apis::DeveloperknowledgeV1::Document

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerknowledge_v1/classes.rb,
lib/google/apis/developerknowledge_v1/representations.rb,
lib/google/apis/developerknowledge_v1/representations.rb

Overview

A Document represents a page of documentation in the Developer Knowledge corpus, like the page at https://docs.cloud.google.com/storage/docs/creating- buckets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Document

Returns a new instance of Document.



243
244
245
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 243

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

Output only. Contains the full content of the document in Markdown format. Corresponds to the JSON property content

Returns:

  • (String)


196
197
198
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 196

def content
  @content
end

#content_length_bytesFixnum

Output only. The length of the content field in bytes. Corresponds to the JSON property contentLengthBytes

Returns:

  • (Fixnum)


201
202
203
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 201

def content_length_bytes
  @content_length_bytes
end

#data_sourceString

Output only. Specifies the data source of the document. Example data source: firebase.google.com Corresponds to the JSON property dataSource

Returns:

  • (String)


207
208
209
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 207

def data_source
  @data_source
end

#descriptionString

Output only. Provides a description of the document. Corresponds to the JSON property description

Returns:

  • (String)


212
213
214
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 212

def description
  @description
end

#nameString

Identifier. Contains the resource name of the document. Format: documents/ uri_without_scheme`Example:documents/docs.cloud.google.com/storage/docs/ creating-buckets Corresponds to the JSON propertyname`

Returns:

  • (String)


219
220
221
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 219

def name
  @name
end

#titleString

Output only. Provides the title of the document. Corresponds to the JSON property title

Returns:

  • (String)


224
225
226
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 224

def title
  @title
end

#update_timeString

Output only. Represents the timestamp when the content or metadata of the document was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


230
231
232
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 230

def update_time
  @update_time
end

#uriString

Output only. Provides the URI of the content, such as docs.cloud.google.com/ storage/docs/creating-buckets. Corresponds to the JSON property uri

Returns:

  • (String)


236
237
238
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 236

def uri
  @uri
end

#viewString

Output only. Specifies the DocumentView of the document. Corresponds to the JSON property view

Returns:

  • (String)


241
242
243
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 241

def view
  @view
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



248
249
250
251
252
253
254
255
256
257
258
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 248

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @content_length_bytes = args[:content_length_bytes] if args.key?(:content_length_bytes)
  @data_source = args[:data_source] if args.key?(:data_source)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @title = args[:title] if args.key?(:title)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
  @view = args[:view] if args.key?(:view)
end