Class: Google::Apis::DeveloperknowledgeV1::Document

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerknowledge_v1/classes.rb,
lib/google/apis/developerknowledge_v1/representations.rb,
lib/google/apis/developerknowledge_v1/representations.rb

Overview

A Document represents a piece of content from the Developer Knowledge corpus.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Document

Returns a new instance of Document.



98
99
100
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 98

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

Output only. Contains the full content of the document in Markdown format. Corresponds to the JSON property content

Returns:

  • (String)


51
52
53
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 51

def content
  @content
end

#content_length_bytesFixnum

Output only. The length of the content field in bytes. Corresponds to the JSON property contentLengthBytes

Returns:

  • (Fixnum)


56
57
58
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 56

def content_length_bytes
  @content_length_bytes
end

#data_sourceString

Output only. Specifies the data source of the document. Example data source: firebase.google.com Corresponds to the JSON property dataSource

Returns:

  • (String)


62
63
64
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 62

def data_source
  @data_source
end

#descriptionString

Output only. Provides a description of the document. Corresponds to the JSON property description

Returns:

  • (String)


67
68
69
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 67

def description
  @description
end

#nameString

Identifier. Contains the resource name of the document. Format: documents/ uri_without_scheme`Example:documents/docs.cloud.google.com/storage/docs/ creating-buckets Corresponds to the JSON propertyname`

Returns:

  • (String)


74
75
76
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 74

def name
  @name
end

#titleString

Output only. Provides the title of the document. Corresponds to the JSON property title

Returns:

  • (String)


79
80
81
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 79

def title
  @title
end

#update_timeString

Output only. Represents the timestamp when the content or metadata of the document was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


85
86
87
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 85

def update_time
  @update_time
end

#uriString

Output only. Provides the URI of the content, such as docs.cloud.google.com/ storage/docs/creating-buckets. Corresponds to the JSON property uri

Returns:

  • (String)


91
92
93
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 91

def uri
  @uri
end

#viewString

Output only. Specifies the DocumentView of the document. Corresponds to the JSON property view

Returns:

  • (String)


96
97
98
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 96

def view
  @view
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



103
104
105
106
107
108
109
110
111
112
113
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 103

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @content_length_bytes = args[:content_length_bytes] if args.key?(:content_length_bytes)
  @data_source = args[:data_source] if args.key?(:data_source)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @title = args[:title] if args.key?(:title)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
  @view = args[:view] if args.key?(:view)
end