Class: Google::Apis::DeveloperknowledgeV1::Document

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerknowledge_v1/classes.rb,
lib/google/apis/developerknowledge_v1/representations.rb,
lib/google/apis/developerknowledge_v1/representations.rb

Overview

A Document represents a piece of content from the Developer Knowledge corpus.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Document

Returns a new instance of Document.



93
94
95
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 93

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

Output only. Contains the full content of the document in Markdown format. Corresponds to the JSON property content

Returns:

  • (String)


51
52
53
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 51

def content
  @content
end

#data_sourceString

Output only. Specifies the data source of the document. Example data source: firebase.google.com Corresponds to the JSON property dataSource

Returns:

  • (String)


57
58
59
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 57

def data_source
  @data_source
end

#descriptionString

Output only. Provides a description of the document. Corresponds to the JSON property description

Returns:

  • (String)


62
63
64
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 62

def description
  @description
end

#nameString

Identifier. Contains the resource name of the document. Format: documents/ uri_without_scheme`Example:documents/docs.cloud.google.com/storage/docs/ creating-buckets Corresponds to the JSON propertyname`

Returns:

  • (String)


69
70
71
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 69

def name
  @name
end

#titleString

Output only. Provides the title of the document. Corresponds to the JSON property title

Returns:

  • (String)


74
75
76
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 74

def title
  @title
end

#update_timeString

Output only. Represents the timestamp when the content or metadata of the document was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


80
81
82
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 80

def update_time
  @update_time
end

#uriString

Output only. Provides the URI of the content, such as docs.cloud.google.com/ storage/docs/creating-buckets. Corresponds to the JSON property uri

Returns:

  • (String)


86
87
88
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 86

def uri
  @uri
end

#viewString

Output only. Specifies the DocumentView of the document. Corresponds to the JSON property view

Returns:

  • (String)


91
92
93
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 91

def view
  @view
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



98
99
100
101
102
103
104
105
106
107
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 98

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @data_source = args[:data_source] if args.key?(:data_source)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @title = args[:title] if args.key?(:title)
  @update_time = args[:update_time] if args.key?(:update_time)
  @uri = args[:uri] if args.key?(:uri)
  @view = args[:view] if args.key?(:view)
end