Class: Google::Apis::DeveloperknowledgeV1::SearchDocumentChunksResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/developerknowledge_v1/classes.rb,
lib/google/apis/developerknowledge_v1/representations.rb,
lib/google/apis/developerknowledge_v1/representations.rb

Overview

Response message for DeveloperKnowledge.SearchDocumentChunks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SearchDocumentChunksResponse

Returns a new instance of SearchDocumentChunksResponse.



172
173
174
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 172

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Optional. Provides a token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


162
163
164
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 162

def next_page_token
  @next_page_token
end

#resultsArray<Google::Apis::DeveloperknowledgeV1::DocumentChunk>

Contains the search results for the given query. Each DocumentChunk in this list contains a snippet of content relevant to the search query. Use the DocumentChunk.parent field of each result with DeveloperKnowledge.GetDocument or DeveloperKnowledge.BatchGetDocuments to retrieve the full document content. Corresponds to the JSON property results



170
171
172
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 170

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



177
178
179
180
# File 'lib/google/apis/developerknowledge_v1/classes.rb', line 177

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @results = args[:results] if args.key?(:results)
end